summaryrefslogtreecommitdiffstats
path: root/PerlQt/perlqt.h
diff options
context:
space:
mode:
Diffstat (limited to 'PerlQt/perlqt.h')
-rw-r--r--PerlQt/perlqt.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/PerlQt/perlqt.h b/PerlQt/perlqt.h
index e4a2c33..7eb240a 100644
--- a/PerlQt/perlqt.h
+++ b/PerlQt/perlqt.h
@@ -1,5 +1,5 @@
-#ifndef PERLQT_H
-#define PERLQT_H
+#ifndef PERLTQT_H
+#define PERLTQT_H
#include "marshall.h"
@@ -19,9 +19,9 @@ extern int do_debug; // evil
extern SV *sv_qapp;
extern int object_count;
-// keep this enum in sync with lib/Qt/debug.pm
+// keep this enum in sync with lib/TQt/debug.pm
-enum QtDebugChannel {
+enum TQtDebugChannel {
qtdb_none = 0x00,
qtdb_ambiguous = 0x01,
qtdb_autoload = 0x02,
@@ -51,4 +51,4 @@ inline smokeperl_object *sv_obj_info(SV *sv) { // ptr on success, null on fail
return o;
}
-#endif // PERLQT_H
+#endif // PERLTQT_H